@@ -1,4 +1,4 @@
-%# Copyright (C) 2006-2008, Thomas Treichl <treichl@users.sourceforge.net>
+%# Copyright (C) 2006-2009, Thomas Treichl <treichl@users.sourceforge.net>
 %# OdePkg - A package for solving ordinary differential equations and more
 %#
 %# This program is free software; you can redistribute it and/or modify
@@ -275,8 +275,29 @@ function [vret] = odepkg_structure_check (varargin)
         end
 
       case 'BDF'
-        if (strcmp (vret.(vfld{vcntarg}), 'on') || ...
-            strcmp (vret.(vfld{vcntarg}), 'off'))
+        if (isempty (vret.(vfld{vcntarg})) || ...
+	    (strcmp (vret.(vfld{vcntarg}), 'on') || ...
+             strcmp (vret.(vfld{vcntarg}), 'off')))
+        else
+          error ('OdePkg:InvalidParameter', ...
+            'Unknown parameter name "%s" or no valid parameter value', ...
+            vfld{vcntarg});
+        end
+
+      case 'NewtonTol'
+        if (isnumeric (vret.(vfld{vcntarg})) && ...
+            isreal    (vret.(vfld{vcntarg})) && ...
+            all       (vret.(vfld{vcntarg}) > 0)) %# 'all' is a MatLab need
+        else
+          error ('OdePkg:InvalidParameter', ...
+            'Unknown parameter name "%s" or no valid parameter value', ...
+            vfld{vcntarg});
+        end
+
+      case 'MaxNewtonIterations'
+        if (isempty (vret.(vfld{vcntarg})) || ...
+            (mod (vret.(vfld{vcntarg}), 1) == 0 && ...
+             vret.(vfld{vcntarg}) > 0))
         else
           error ('OdePkg:InvalidParameter', ...
             'Unknown parameter name "%s" or no valid parameter value', ...
@@ -385,8 +406,15 @@ function [vret] = odepkg_structure_check (varargin)
 %!test  A = odeset ('MaxOrder', []);
 %!test  A = odeset ('BDF', 'on');
 %!test  A = odeset ('BDF', 'off');
+%!test  A = odeset ('BDF', []);
 %!error A = odeset ('BDF', [1, 2; 3, 4]);
-%!error A = odeset ('BDF', []);
+%!test  A = odeset ('NewtonTol', []);
+%!test  A = odeset ('NewtonTol', 1e-3);
+%!test  A = odeset ('NewtonTol', [1e-3, 1e-3, 1e-3]);
+%!error A = odeset ('NewtonTol', 'string');
+%!test  A = odeset ('MaxNewtonIterations', []);
+%!test  A = odeset ('MaxNewtonIterations', 2);
+%!error A = odeset ('MaxNewtonIterations', 'string');
 
 %!demo
 %! # Return the checked OdePkg options structure that is created by
