@@ -1,4 +1,4 @@
-%# Copyright (C) 2006-2008, Thomas Treichl <treichl@users.sourceforge.net>
+%# Copyright (C) 2006-2009, Thomas Treichl <treichl@users.sourceforge.net>
 %# OdePkg - A package for solving ordinary differential equations and more
 %#
 %# This program is free software; you can redistribute it and/or modify
@@ -63,7 +63,9 @@ function [vret] = odeset (varargin)
      'MassSingular', 'maybe', ...
      'InitialSlope', [], ...
      'MaxOrder', [], ...
-     'BDF', 'off');
+     'BDF', [], ...
+     'NewtonTol', [], ...
+     'MaxNewtonIterations', []);
 
   %# Check number and types of all input arguments
   if (nargin == 0 && nargout == 1)
