@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
+Copyright (C) 2007-2009, Thomas Treichl <treichl@users.sourceforge.net>
 OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
@@ -369,9 +369,10 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // The option NormControl will be ignored by this solver, the core
   // Fortran solver doesn't support this option
   octave_value vnorm = odepkg_auxiliary_getmapvalue ("NormControl", vodeopt);
-  if (!vnorm.is_empty () && (vnorm.string_value ().compare ("off") != 0))
-    warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"NormControl\" will be ignored by this solver");
+  if (!vnorm.is_empty ())
+    if (vnorm.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"NormControl\" will be ignored by this solver");
 
   // The option NonNegative will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -445,9 +446,10 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // The option MStateDependence will be ignored by this solver. We
   // can't handle Mass-matrix options with IDE problems
   octave_value vmst = odepkg_auxiliary_getmapvalue ("MStateDependence", vodeopt);
-  if (!vmst.is_empty () && (vmst.string_value ().compare ("weak") != 0))
-    warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"MStateDependence\" will be ignored by this solver");
+  if (!vmst.is_empty ())
+    if (vmst.string_value ().compare ("weak") != 0)
+      warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"MStateDependence\" will be ignored by this solver");
 
   // The option MvPattern will be ignored by this solver. We
   // can't handle Mass-matrix options with IDE problems
@@ -459,9 +461,10 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // The option MvPattern will be ignored by this solver. We
   // can't handle Mass-matrix options with IDE problems
   octave_value vmsing = odepkg_auxiliary_getmapvalue ("MassSingular", vodeopt);
-  if (!vmsing.is_empty () && (vmsing.string_value ().compare ("maybe") != 0))
-    warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"MassSingular\" will be ignored by this solver");
+  if (!vmsing.is_empty ())
+    if (vmsing.string_value ().compare ("maybe") != 0)
+      warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"MassSingular\" will be ignored by this solver");
 
   // The option InitialSlope will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -486,11 +489,24 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 
   // The option BDF will be ignored because this is a BDF solver
   octave_value vbdf = odepkg_auxiliary_getmapvalue ("BDF", vodeopt);
-  if (vbdf.string_value () != "on") {
-    vbdf = "on";
+  if (!vbdf.is_empty ())
+    if (vbdf.string_value () != "on") {
+      vbdf = "on"; warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"BDF\" set \"off\", new value \"on\" is used");
+    }
+
+  // The option NewtonTol and MaxNewtonIterations will be ignored by
+  // this solver, IT NEEDS TO BE CHECKED IF THE FORTRAN CORE SOLVER
+  // CAN HANDLE THESE OPTIONS
+  octave_value vntol = odepkg_auxiliary_getmapvalue ("NewtonTol", vodeopt);
+  if (!vntol.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"BDF\" set \"off\", new value \"on\" is used");
-  }
+      "Option \"NewtonTol\" will be ignored by this solver");
+  octave_value vmaxnewton = 
+    odepkg_auxiliary_getmapvalue ("MaxNewtonIterations", vodeopt);
+  if (!vmaxnewton.is_empty ())
+    warning_with_id ("OdePkg:InvalidOption", 
+      "Option \"MaxNewtonIterations\" will be ignored by this solver");
 
 /* Start MAINPROCESSING, set up all variables that are needed by this
  * solver and then initialize the solver function and get into the
@@ -549,7 +565,7 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // If the user has set an OutputFcn or an Events function then
   // initialize these IO-functions for further use
   octave_value vtim (T); octave_value vsol (vY); octave_value vyds (vYPRIME);
-  odepkg_auxiliary_solstore (vtim, vsol, voutsel, 0);
+  odepkg_auxiliary_solstore (vtim, vsol, 0);
   if (!vplot.is_empty ()) 
     odepkg_auxiliary_evalplotfun (vplot, voutsel, args(1), args(2), vddaskrextarg, 0);
 
@@ -598,14 +614,14 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
       // This call of the Fortran solver has been successful so let us
       // plot the output and save the results
       for (octave_idx_type vcnt = 0; vcnt < vddaskrneqn; vcnt++) {
-	vcres(vcnt) = Y[vcnt]; vydrs(vcnt) = YPRIME[vcnt];
+        vcres(vcnt) = Y[vcnt]; vydrs(vcnt) = YPRIME[vcnt];
       }
       vsol = vcres; vyds = vydrs; vtim = T;
 
       if (!vevents.is_empty ()) {
         veveideargs(0) = vsol;
         veveideargs(1) = vyds;
-	veveidearg = veveideargs;
+        veveidearg = veveideargs;
         veveres = odepkg_auxiliary_evaleventfun (vevents, vtim, veveidearg, vddaskrextarg, 1);
         if (!veveres(0).cell_value ()(0).is_empty ())
           if (veveres(0).cell_value ()(0).int_value () == 1) {
@@ -624,7 +640,7 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
         }
       }
 
-      odepkg_auxiliary_solstore (vtim, vsol, voutsel, 1);
+      odepkg_auxiliary_solstore (vtim, vsol, 1);
     }
   }
 
@@ -649,7 +665,7 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // Return the results that have been stored in the
   // odepkg_auxiliary_solstore function
   octave_value vtres, vyres;
-  odepkg_auxiliary_solstore (vtres, vyres, voutsel, 2);
+  odepkg_auxiliary_solstore (vtres, vyres, 2);
 
   // Get the stats information as an Octave_map if the option 'Stats'
   // has been set with odeset 
@@ -853,6 +869,14 @@ odekdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 %!  vopt = odeset ('BDF', 'on');
 %!  vsol = odekdi (@fpol, [0, 2], [2; 0], [0; -2], vopt);
 %!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set NewtonTol option to something else than default
+%!  vopt = odeset ('NewtonTol', 1e-3);
+%!  vsol = odekdi (@fpol, [0, 2], [2; 0], [0; -2], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set MaxNewtonIterations option to something else than default
+%!  vopt = odeset ('MaxNewtonIterations', 2);
+%!  vsol = odekdi (@fpol, [0, 2], [2; 0], [0; -2], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
 %!
 %!  warning ('on', 'OdePkg:InvalidOption');
 */
