@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
+Copyright (C) 2007-2009, Thomas Treichl <treichl@users.sourceforge.net>
 OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
@@ -398,9 +398,10 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option NormControl will be ignored by this solver, the core
   // Fortran solver doesn't support this option
   octave_value vnorm = odepkg_auxiliary_getmapvalue ("NormControl", vodeopt);
-  if (!vnorm.is_empty () && (vnorm.string_value ().compare ("off") != 0))
-    warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"NormControl\" will be ignored by this solver");
+  if (!vnorm.is_empty ())
+    if (vnorm.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"NormControl\" will be ignored by this solver");
 
   // The option NonNegative will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -482,9 +483,10 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
   vmebdfdaemassstate = odepkg_auxiliary_getmapvalue ("MStateDependence", vodeopt);
-  if (vmebdfdaemassstate.string_value ().compare ("weak") != 0) // 'weak' is default
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"MStateDependence\" will be ignored by this solver");
+  if (!vmebdfdaemassstate.is_empty ())
+    if (vmebdfdaemassstate.string_value ().compare ("weak") != 0) // 'weak' is default
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MStateDependence\" will be ignored by this solver");
 
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
@@ -496,9 +498,10 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option MassSingular will be ignored by this solver, the
   // core Fortran solver doesn't support this option
   octave_value vmsing = odepkg_auxiliary_getmapvalue ("MassSingular", vodeopt);
-  if (!vmsing.is_empty () && (vmsing.string_value ().compare ("maybe") != 0))
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"MassSingular\" will be ignored by this solver");
+  if (!vmsing.is_empty ())
+    if (vmsing.string_value ().compare ("maybe") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MassSingular\" will be ignored by this solver");
 
   // The option InitialSlope will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -525,11 +528,23 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option BDF will be ignored because this is a BDF solver
   octave_value vbdf = odepkg_auxiliary_getmapvalue ("BDF", vodeopt);
-  if (vbdf.string_value () != "on") {
-    vbdf = "on";
+  if (vbdf.is_string ())
+    if (vbdf.string_value () != "on") {
+      vbdf = "on"; warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"BDF\" set \"off\", new value \"on\" is used");
+    }
+  // The option NewtonTol and MaxNewtonIterations will be ignored by
+  // this solver, IT NEEDS TO BE CHECKED IF THE FORTRAN CORE SOLVER
+  // CAN HANDLE THESE OPTIONS
+  octave_value vntol = odepkg_auxiliary_getmapvalue ("NewtonTol", vodeopt);
+  if (!vntol.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"BDF\" set \"off\", new value \"on\" is used");
-  }
+      "Option \"NewtonTol\" will be ignored by this solver");
+  octave_value vmaxnewton = 
+    odepkg_auxiliary_getmapvalue ("MaxNewtonIterations", vodeopt);
+  if (!vmaxnewton.is_empty ())
+    warning_with_id ("OdePkg:InvalidOption", 
+      "Option \"MaxNewtonIterations\" will be ignored by this solver");
 
 /* Start MAINPROCESSING, set up all variables that are needed by this
  * solver and then initialize the solver function and get into the
@@ -577,7 +592,7 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Check if the user has set some of the options "OutputFcn", "Events"
   // etc. and initialize the plot, events and the solstore functions
   octave_value vtim (T0); octave_value vsol (vY0);
-  odepkg_auxiliary_solstore (vtim, vsol, voutsel, 0);
+  odepkg_auxiliary_solstore (vtim, vsol, 0);
   if (!vplot.is_empty ()) odepkg_auxiliary_evalplotfun 
     (vplot, voutsel, args(1), args(2), vmebdfdaeextarg, 0);
   if (!vevents.is_empty ()) odepkg_auxiliary_evaleventfun 
@@ -648,7 +663,7 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
           return (vretval);
         }
       }
-      odepkg_auxiliary_solstore (vtim, vsol, voutsel, 1);
+      odepkg_auxiliary_solstore (vtim, vsol, 1);
     }
   }
   else { // if (vTIME.length () > 2) we have all the time values needed
@@ -695,7 +710,7 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
           return (vretval);
         }
       }
-     odepkg_auxiliary_solstore (vtim, vsol, voutsel, 1);
+     odepkg_auxiliary_solstore (vtim, vsol, 1);
     }
   }
 
@@ -715,7 +730,7 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Return the results that have been stored in the
   // odepkg_auxiliary_solstore function
   octave_value vtres, vyres;
-  odepkg_auxiliary_solstore (vtres, vyres, voutsel, 2);
+  odepkg_auxiliary_solstore (vtres, vyres, 2);
   // odepkg_auxiliary_solstore (vtres, vyres, voutsel, 100);
 
   // Get the stats information as an Octave_map if the option 'Stats'
@@ -931,7 +946,19 @@ odebda (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 %! %# test for MvPattern option is missing
 %! %# test for InitialSlope option is missing
 %! %# test for MaxOrder option is missing
-%! %# test for BDF option is missing
+%!
+%!test %# BDF option set "off"
+%!  vopt = odeset ('BDF', 'off');
+%!  vsol = odebda (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set NewtonTol option to something else than default
+%!  vopt = odeset ('NewtonTol', 1e-3);
+%!  vsol = odebda (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set MaxNewtonIterations option to something else than default
+%!  vopt = odeset ('MaxNewtonIterations', 2);
+%!  vsol = odebda (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
 %!
 %!  warning ('on', 'OdePkg:InvalidOption');
 */
