@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
+Copyright (C) 2007-2009, Thomas Treichl <treichl@users.sourceforge.net>
 OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
@@ -212,7 +212,7 @@ octave_idx_type odepkg_radau_solfcn
 
   // Save the solutions that come from the Fortran core solver if this
   // is not the initial first call to this function
-  if (NR > 1) odepkg_auxiliary_solstore (vt, vy, vradauoutsel, 1);
+  if (NR > 1) odepkg_auxiliary_solstore (vt, vy, 1);
 
   // Check if an 'OutputFcn' has been set by the user (including the
   // values of the options for 'OutputSel' and 'Refine')
@@ -406,9 +406,10 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option NormControl will be ignored by this solver, the core
   // Fortran solver doesn't support this option
   octave_value vnorm = odepkg_auxiliary_getmapvalue ("NormControl", vodeopt);
-  if (!vnorm.is_empty () && (vnorm.string_value ().compare ("off") != 0))
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"NormControl\" will be ignored by this solver");
+  if (!vnorm.is_empty ())
+    if (vnorm.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"NormControl\" will be ignored by this solver");
 
   // The option NonNegative will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -438,10 +439,8 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // option can be set by the user to another value than default value
   octave_value vinitstep = odepkg_auxiliary_getmapvalue ("InitialStep", vodeopt);
   if (args(1).length () > 2) {
-    if (!vinitstep.is_empty ())
-      warning_with_id ("OdePkg:InvalidOption",
-       "Option \"InitialStep\" will be ignored if fixed time stamps are given");
-    vinitstep = args(1).vector_value ()(1);
+    error_with_id ("OdePkg:InvalidOption",
+      "Fixed time stamps are not supported by this solver");
   }
   if (vinitstep.is_empty ()) {
     vinitstep = 1.0e-6;
@@ -481,9 +480,10 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option Vectorized will be ignored by this solver, the core
   // Fortran solver doesn't support this option
   octave_value vradauvectorize = odepkg_auxiliary_getmapvalue ("Vectorized", vodeopt);
-  if (vradauvectorize.string_value ().compare ("off") != 0)
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"Vectorized\" will be ignored by this solver");
+  if (!vradauvectorize.is_empty ())
+    if (vradauvectorize.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"Vectorized\" will be ignored by this solver");
 
   // Implementation of the option 'Mass' has been finished, these
   // options can be set by the user to another value than default
@@ -499,9 +499,10 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
   vradaumassstate = odepkg_auxiliary_getmapvalue ("MStateDependence", vodeopt);
-  if (vradaumassstate.string_value ().compare ("weak") != 0) // 'weak' is default
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"MStateDependence\" will be ignored by this solver");
+  if (!vradaumassstate.is_empty ())
+    if (vradaumassstate.string_value ().compare ("weak") != 0) // 'weak' is default
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MStateDependence\" will be ignored by this solver");
 
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
@@ -513,9 +514,10 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option MassSingular will be ignored by this solver, the
   // core Fortran solver doesn't support this option
   octave_value vmsing = odepkg_auxiliary_getmapvalue ("MassSingular", vodeopt);
-  if (!vmsing.is_empty () && (vmsing.string_value ().compare ("maybe") != 0))
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"MassSingular\" will be ignored by this solver");
+  if (!vmsing.is_empty ())
+    if (vmsing.string_value ().compare ("maybe") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MassSingular\" will be ignored by this solver");
 
   // The option InitialSlope will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -534,9 +536,23 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option BDF will be ignored by this solver, the core Fortran
   // solver doesn't support this option
   octave_value vbdf = odepkg_auxiliary_getmapvalue ("BDF", vodeopt);
-  if (vbdf.string_value ().compare ("off") != 0)
+  if (!vbdf.is_empty ())
+    if (vbdf.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"BDF\" will be ignored by this solver");
+
+  // The option NewtonTol and MaxNewtonIterations will be ignored by
+  // this solver, IT NEEDS TO BE CHECKED IF THE FORTRAN CORE SOLVER
+  // CAN HANDLE THESE OPTIONS
+  octave_value vntol = odepkg_auxiliary_getmapvalue ("NewtonTol", vodeopt);
+  if (!vntol.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"BDF\" will be ignored by this solver");
+      "Option \"NewtonTol\" will be ignored by this solver");
+  octave_value vmaxnewton = 
+    odepkg_auxiliary_getmapvalue ("MaxNewtonIterations", vodeopt);
+  if (!vmaxnewton.is_empty ())
+    warning_with_id ("OdePkg:InvalidOption", 
+      "Option \"MaxNewtonIterations\" will be ignored by this solver");
 
 /* Start MAINPROCESSING, set up all variables that are needed by this
  * solver and then initialize the solver function and get into the
@@ -580,7 +596,7 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // etc. and initialize the plot, events and the solstore functions
   octave_value vtim = args(1).vector_value ()(0);
   octave_value vsol = args(2);
-  odepkg_auxiliary_solstore (vtim, vsol, vradauoutsel, 0);
+  odepkg_auxiliary_solstore (vtim, vsol, 0);
   if (!vradaupltfun.is_empty ()) odepkg_auxiliary_evalplotfun 
     (vradaupltfun, vradauoutsel, args(1), args(2), vradauextarg, 0);
   if (!vradauevefun.is_empty ())
@@ -609,7 +625,7 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Return the results that have been stored in the
   // odepkg_auxiliary_solstore function
   octave_value vtres, vyres;
-  odepkg_auxiliary_solstore (vtres, vyres, vradauoutsel, 2);
+  odepkg_auxiliary_solstore (vtres, vyres, 2);
 
   // Set up variables to make it possible to call the cleanup
   // functions of 'OutputFcn' and 'Events' if any
@@ -724,7 +740,9 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 %!error %# input argument number two
 %!  B = ode2r (@fpol, 1, [3 15 1]);
 %!error %# input argument number three
-%!  B = ode2r (@flor, [0 25], 1);
+%!  B = ode2r (@fpol, [0 25], 1);
+%!error %# fixed step sizes not supported
+%!  B = ode2r (@fpol, [0:0.1:2], [2 0]);
 %!test %# one output argument
 %!  vsol = ode2r (@fpol, [0 2], [2 0]);
 %!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
@@ -838,7 +856,19 @@ ode2r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 %! %# test for MvPattern option is missing
 %! %# test for InitialSlope option is missing
 %! %# test for MaxOrder option is missing
-%! %# test for BDF option is missing
+%!
+%!test %# Set BDF option to something else than default
+%!  vopt = odeset ('BDF', 'on');
+%!  vsol = ode2r (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set NewtonTol option to something else than default
+%!  vopt = odeset ('NewtonTol', 1e-3);
+%!  vsol = ode2r (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set MaxNewtonIterations option to something else than default
+%!  vopt = odeset ('MaxNewtonIterations', 2);
+%!  vsol = ode2r (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
 %!
 %!  warning ('on', 'OdePkg:InvalidOption');
 */
