@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
+Copyright (C) 2007-2009, Thomas Treichl <treichl@users.sourceforge.net>
 OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
@@ -212,7 +212,7 @@ octave_idx_type odepkg_radau5_solfcn
 
   // Save the solutions that come from the Fortran core solver if this
   // is not the initial first call to this function
-  if (NR > 1) odepkg_auxiliary_solstore (vt, vy, vradau5outsel, 1);
+  if (NR > 1) odepkg_auxiliary_solstore (vt, vy, 1);
 
   // Check if an 'OutputFcn' has been set by the user (including the
   // values of the options for 'OutputSel' and 'Refine')
@@ -406,9 +406,10 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option NormControl will be ignored by this solver, the core
   // Fortran solver doesn't support this option
   octave_value vnorm = odepkg_auxiliary_getmapvalue ("NormControl", vodeopt);
-  if (!vnorm.is_empty () && (vnorm.string_value ().compare ("off") != 0))
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"NormControl\" will be ignored by this solver");
+  if (!vnorm.is_empty ())
+    if (vnorm.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"NormControl\" will be ignored by this solver");
 
   // The option NonNegative will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -438,10 +439,8 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // option can be set by the user to another value than default value
   octave_value vinitstep = odepkg_auxiliary_getmapvalue ("InitialStep", vodeopt);
   if (args(1).length () > 2) {
-    if (!vinitstep.is_empty ())
-      warning_with_id ("OdePkg:InvalidOption",
-       "Option \"InitialStep\" will be ignored if fixed time stamps are given");
-    vinitstep = args(1).vector_value ()(1);
+    error_with_id ("OdePkg:InvalidOption",
+      "Fixed time stamps are not supported by this solver");
   }
   if (vinitstep.is_empty ()) {
     vinitstep = 1.0e-6;
@@ -481,9 +480,10 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option Vectorized will be ignored by this solver, the core
   // Fortran solver doesn't support this option
   octave_value vradau5vectorize = odepkg_auxiliary_getmapvalue ("Vectorized", vodeopt);
-  if (vradau5vectorize.string_value ().compare ("off") != 0)
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"Vectorized\" will be ignored by this solver");
+  if (!vradau5vectorize.is_empty ())
+    if (vradau5vectorize.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"Vectorized\" will be ignored by this solver");
 
   // Implementation of the option 'Mass' has been finished, these
   // options can be set by the user to another value than default
@@ -499,9 +499,10 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
   vradau5massstate = odepkg_auxiliary_getmapvalue ("MStateDependence", vodeopt);
-  if (vradau5massstate.string_value ().compare ("weak") != 0) // 'weak' is default
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"MStateDependence\" will be ignored by this solver");
+  if (!vradau5massstate.is_empty ())
+    if (vradau5massstate.string_value ().compare ("weak") != 0) // 'weak' is default
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MStateDependence\" will be ignored by this solver");
 
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
@@ -513,9 +514,10 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option MassSingular will be ignored by this solver, the
   // core Fortran solver doesn't support this option
   octave_value vmsing = odepkg_auxiliary_getmapvalue ("MassSingular", vodeopt);
-  if (!vmsing.is_empty () && (vmsing.string_value ().compare ("maybe") != 0))
-    warning_with_id ("OdePkg:InvalidOption",
-      "Option \"MassSingular\" will be ignored by this solver");
+  if (!vmsing.is_empty ())
+    if (vmsing.string_value ().compare ("maybe") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MassSingular\" will be ignored by this solver");
 
   // The option InitialSlope will be ignored by this solver, the core
   // Fortran solver doesn't support this option
@@ -534,9 +536,32 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option BDF will be ignored by this solver, the core Fortran
   // solver doesn't support this option
   octave_value vbdf = odepkg_auxiliary_getmapvalue ("BDF", vodeopt);
-  if (vbdf.string_value ().compare ("off") != 0)
+  if (!vbdf.is_empty ())
+    if (vbdf.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"BDF\" will be ignored by this solver");
+
+  // Implementation of the option NewtonTol has been finished, this
+  // option can be set by the user to another value than default value
+  octave_value vNTOL = odepkg_auxiliary_getmapvalue ("NewtonTol", vodeopt);
+  if (vNTOL.is_empty ()) {
+    vNTOL = 0;
     warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"BDF\" will be ignored by this solver");
+      "Option \"NewtonTol\" not set, default value is used");
+  }
+
+  // Implementation of the option MaxNewtonIterations has been finished, this
+  // option can be set by the user to another value than default value
+  octave_value vmaxnit = 
+    odepkg_auxiliary_getmapvalue ("MaxNewtonIterations", vodeopt);
+  if (vmaxnit.is_empty ()) {
+    vmaxnit = 7; warning_with_id ("OdePkg:InvalidOption", 
+      "Option \"MaxNewtonIterations\" not set, default value 7 is used");
+  }
+  else if (vmaxnit.int_value () < 1) {
+    vmaxnit = 7; warning_with_id ("OdePkg:InvalidOption", 
+      "Option \"MaxNewtonIterations\" is zero, default value 7 is used");
+  }
 
 /* Start MAINPROCESSING, set up all variables that are needed by this
  * solver and then initialize the solver function and get into the
@@ -573,14 +598,16 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   octave_idx_type IDID = 0;
 
   IWORK[0] = 1;  // Switch for transformation of Jacobian into Hessenberg form
+  IWORK[2] = vmaxnit.int_value ();     // Maximum number of Newton iterations
   WORK[2]  = -1; // Recompute Jacobian after every succesful step
+  WORK[3]  = vNTOL.double_value (); // Tolerance of Newton iteration
   WORK[6]  = vmaxstep.double_value (); // Set the maximum step size
 
   // Check if the user has set some of the options "OutputFcn", "Events"
   // etc. and initialize the plot, events and the solstore functions
   octave_value vtim = args(1).vector_value ()(0);
   octave_value vsol = args(2);
-  odepkg_auxiliary_solstore (vtim, vsol, vradau5outsel, 0);
+  odepkg_auxiliary_solstore (vtim, vsol, 0);
   if (!vradau5pltfun.is_empty ()) odepkg_auxiliary_evalplotfun 
     (vradau5pltfun, vradau5outsel, args(1), args(2), vradau5extarg, 0);
   if (!vradau5evefun.is_empty ())
@@ -610,7 +637,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Return the results that have been stored in the
   // odepkg_auxiliary_solstore function
   octave_value vtres, vyres;
-  odepkg_auxiliary_solstore (vtres, vyres, vradau5outsel, 2);
+  odepkg_auxiliary_solstore (vtres, vyres, 2);
 
   // Set up variables to make it possible to call the cleanup
   // functions of 'OutputFcn' and 'Events' if any
@@ -628,6 +655,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   
   // Get the stats information as an Octave_map if the option 'Stats'
   // has been set with odeset
+  // "nsteps", "nfailed", "nfevals", "npds", "ndecomps", "nlinsols"
   octave_value_list vstatinput;
   vstatinput(0) = IWORK[16];
   vstatinput(1) = IWORK[17];
@@ -725,6 +753,8 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 %!  B = ode5r (@fpol, 1, [3 15 1]);
 %!error %# input argument number three
 %!  B = ode5r (@flor, [0 25], 1);
+%!error %# fixed step sizes not supported
+%!  B = ode5r (@fpol, [0:0.1:2], [2 0]);
 %!test %# one output argument
 %!  vsol = ode5r (@fpol, [0 2], [2 0]);
 %!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
@@ -838,7 +868,19 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 %! %# test for MvPattern option is missing
 %! %# test for InitialSlope option is missing
 %! %# test for MaxOrder option is missing
-%! %# test for BDF option is missing
+%!
+%!test %# Set BDF option to something else than default
+%!  vopt = odeset ('BDF', 'on');
+%!  vsol = ode5r (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set NewtonTol option to something else than default
+%!  vopt = odeset ('NewtonTol', 1e-3);
+%!  vsol = ode5r (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set MaxNewtonIterations option to something else than default
+%!  vopt = odeset ('MaxNewtonIterations', 2);
+%!  vsol = ode5r (@fpol, [0 2], [2 0], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
 %!
 %!  warning ('on', 'OdePkg:InvalidOption');
 */
